@@ -63,10 +63,13 @@ class ArimaEstimator:
         # Check if the time has consistent frequency
         self._validate_ds_freq(history_pd, self._frequency_unit)
 
-        # Impute missing time steps
-        history_pd = self._fill_missing_time_steps(history_pd, self._frequency_unit)
+        history_periods = utils.calculate_period_differences(
+            history_pd['ds'].min(), history_pd['ds'].max(), self._frequency_unit
+        )
+        if history_periods + 1 != history_pd['ds'].size:
+            # Impute missing time steps
+            history_pd = self._fill_missing_time_steps(history_pd, self._frequency_unit)
 
-        history_timedelta = history_pd['ds'].max() - history_pd['ds'].min()
 
         # Tune seasonal periods
         best_result = None
@@ -74,9 +77,8 @@ class ArimaEstimator:
         for m in self._seasonal_periods:
             try:
                 # this check mirrors the the default behavior by prophet
-                seasonality_timedelta = pd.to_timedelta(m, unit=self._frequency_unit)
-                if history_timedelta < 2 * seasonality_timedelta:
-                    _logger.warning(f"Skipping seasonal_period={m} ({seasonality_timedelta}). Dataframe timestamps must span at least two seasonality periods, but only spans {history_timedelta}")
+                if history_periods < 2 * m:
+                    _logger.warning(f"Skipping seasonal_period={m} ({self._frequency_unit}). Dataframe timestamps must span at least two seasonality periods, but only spans {history_periods} {self._frequency_unit}""")
                     continue
                 # Prophet also rejects the seasonality periods if the seasonality period timedelta is less than the shortest timedelta in the dataframe.
                 # However, this cannot happen in ARIMA because _fill_missing_time_steps imputes values for each _frequency_unit,
@@ -141,8 +143,10 @@ class ArimaEstimator:
     @staticmethod
     def _validate_ds_freq(df: pd.DataFrame, frequency: str):
         start_ds = df["ds"].min()
-        diff = (df["ds"] - start_ds) / pd.Timedelta(1, unit=frequency)
-        if not diff.apply(float.is_integer).all():
+        consistency = df["ds"].apply(lambda x:
+            utils.is_frequency_consistency(start_ds, x, frequency)
+        ).all()
+        if not consistency:
             raise ValueError(
                 f"Input time column includes different frequency than the specified frequency {frequency}."
             )
